@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.130307';
+our $VERSION = '0.130919';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -15,8 +15,10 @@ use Acme::CPANAuthors::Register (
     AHIGUCHI  => 'Akira Higuchi',
     AHIGUTI   => 'Akira Higuchi',
     AHIROSE   => 'Akira HIROSE',
+    AINAME    => 'Satoshi Namai',
     AKIHITO   => 'Akihito Takeda',
     AKIRA     => 'Akira Hangai',
+    AKITSUO   => 'Hiroaki Otsu',
     AKIYM     => 'Takumi Akiyama',
     AKOBA     => 'Atsushi Kobayashi',
     AKXLIX    => 'azuma, kuniyuki',
@@ -55,6 +57,7 @@ use Acme::CPANAuthors::Register (
     DGSCOPE   => 'Masayuki Komori',
     DMAKI     => 'Daisuke Maki',
     DRAWNBOY  => 'Hideaki Tanaka',
+    DSYRTM    => 'Mitsuru Yasuda',
     FNOBI     => 'Fujisawa Shin',
     FUJIMURA  => 'FUJIMURA Yuki',
     FUJISAWA  => 'Mizuki Fujisawa',
@@ -68,6 +71,7 @@ use Acme::CPANAuthors::Register (
     GOCCY     => 'Masaaki Goshima',
     GOLOGO    => 'Yohei Yamaguchi',
     GUNYA     => 'GUNYARA-KUN',
+    HAAZIME   => 'Hajime Sueyoshi',
     HAKOBE    => 'Yohei Fushii',
     HAMANO    => 'Tsukasa Hamano',
     HANDLE    => 'NAGATA Hiroaki',
@@ -84,6 +88,7 @@ use Acme::CPANAuthors::Register (
     HHORIUCHI => 'Hiroki Horiuchi',
     HIDE      => 'Hideo Kimura',
     HIDEDEN   => 'Hideyuki Kakiuchi',
+    HIDEHIGO  => 'Akihide Higo',
     HIGU      => 'Higuchi hiroyuki',
     HIKARINE  => 'Hajime Kurita',
     HIMACHOCO => 'Wataru Seto',
@@ -97,12 +102,15 @@ use Acme::CPANAuthors::Register (
     HIROSE    => 'HIROSE Masaaki',
     HIROYUKI  => 'Hiroyuki Yamanaka',
     HIROYUKIM => 'Yamanaka Hiroyuki',
+    HISAICHI  => 'HISADA KAZUKI',
     HISAJU    => 'Kikumoto HIsatoshi',
+    HIXI      => 'Hiroyoshi HOUCHI',
     HRYK      => 'Hiroyuki Nakamura',
     HKOBA     => 'KOBAYASI, Hiroaki',
     HOKKE     => 'Yoichi Hirota',
     HOLLY     => 'Akira Horimoto',
     HORIUCHI  => 'Yasuhiro Horiuchi',
+    HOTSU     => 'Hiroaki Otsu',
     HRK       => 'Haruka Kataoka',
     HWAT      => 'WATANABE Hiroaki',
     ICHI      => 'Takuya Ichikawa',
@@ -112,6 +120,8 @@ use Acme::CPANAuthors::Register (
     IKUTA     => 'Masahito Ikuta',
     IIZUKA    => 'Nao Iizuka',
     INA       => 'INABA Hitoshi',
+    INFINITH  => 'Hiroshi Tashiro',
+    INGKTDS   => 'Inagaki Tadashi',
     ISHIGAKI  => 'Kenichi Ishigaki',
     ISKATA    => 'Isao Katayama',
     ISOYA     => 'Ryohei Isoya',
@@ -142,6 +152,7 @@ use Acme::CPANAuthors::Register (
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
     KINSAN    => 'Hitoshi Yokozawa',
+    KIRIRIMOD => 'Yuichi Kiri',
     KISEKI    => 'keita iseki',
     KITAMAKI  => 'ryo kitamaki',
     KIWANAMI  => 'Masashi Sakurai',
@@ -158,6 +169,7 @@ use Acme::CPANAuthors::Register (
     KONDO     => 'Yoshiyuki KONDO',
     KOPUG     => 'Masahiro Funakoshi',
     KOYACHI   => 'Tsutomu Koyachi',
+    KPEE      => 'Kiyoaki KATAKURA',
     KSUZUKI   => 'Ken Suzuki',
     KTAKATA   => 'Ken Takata',
     KTAT      => 'Kato Atsushi',
@@ -185,6 +197,8 @@ use Acme::CPANAuthors::Register (
     LUSHE     => 'Masatoshi Mizuno',
     LYOKATO   => 'Lyo Kato',
     MACOPY    => 'Makoto Taniwaki',
+    MACOTASU  => 'Shiga Makoto',
+    MAEDAMA   => 'Shuntaro Maeda',
     MAGICDRIV => 'Hiroshi IKEGAMI',
     MAHIRO    => 'Mahiro Ando',
     MAHITO    => 'Hogelist',
@@ -192,6 +206,7 @@ use Acme::CPANAuthors::Register (
     MAKAMAKA  => 'Makamaka Hannyaharamitu',
     MAKOTO    => 'Shin Honda',
     MAND      => 'Yuki Manno',
+    MANUOKADA => 'Manabu Okada',
     MAOE      => 'Mitsutoshi Aoe',
     MASAHITO  => 'Masahito Yoshida',
     MASAKI    => 'NAKAGAWA Masaki',
@@ -245,11 +260,14 @@ use Acme::CPANAuthors::Register (
     NOGUCHI   => 'Tatsuya Noguchi',
     NORITAKA  => 'Noritaka Okabe',
     NOZZZZZ   => 'Tetsunari Nozaki',
+    NTAKANASI => 'Nao Takanashi',
     NTSUTSUMI => 'Naoya Tsutsumi',
+    NYAGAO    => 'Takahiro Nagao',
     NYARLA    => 'Naoki Okamura',
     OGATA     => 'OGATA Tetsuji',
     OGAWA     => 'Hirotaka Ogawa',
     OKAMUUU   => 'Masao Okamura',
+    OKLAHOMER => 'Go Hagiwara',
     OINUME    => 'Kazuhiro Oinuma',
     OISHI     => 'Eisuke Oishi',
     ONISHI    => 'Yasuhiro Onishi',
@@ -267,6 +285,7 @@ use Acme::CPANAuthors::Register (
     POCKET    => 'Masato Sogame',
     POPPEN    => 'Shinsuke Matsui',
     QUEEN     => 'Yasuhiro Miyazaki',
+    RIMFS     => 'Yuichiro Tanaka',
     RINTARO   => 'Rintaro Ishizaki',
     RITOU     => 'Ryo Ito',
     RIYWO     => 'Ryosuke IWANAGA',
@@ -307,8 +326,10 @@ use Acme::CPANAuthors::Register (
     SNUMANO   => 'Shugo Numano',
     SONGMU    => 'Masayuki Matsuki',
     SOTSA     => 'Shinichiro Sato',
+    SPRINGMT  => 'Makoto Haruyama',
     SSEI      => 'Shinichiro Sei',
     STAKASHIO => 'Shin Takashio',
+    SUGA      => 'suga masashi',
     SUGMAK    => 'Makoto Sugiyama',
     SUGYAN    => 'Yoshihiro Sugi',
     SUHARA    => 'Yoshihiko Suhara',
@@ -363,6 +384,7 @@ use Acme::CPANAuthors::Register (
     TONODERA  => 'Takahiro Onodera',
     TOONA     => 'Naoto Ishikawa',
     TOPIA     => 'Tatuya Noda',
+    TORITSUYO => 'Tsuyoshi Torii',
     TORU      => 'Toru Hisai',
     TOSHIFJW  => 'Toshimitsu FUJIWARA',
     TOSHIOITO => 'Toshio Ito',
@@ -419,6 +441,7 @@ use Acme::CPANAuthors::Register (
     YUKINOBU  => 'NAGAYASU Yukinobu',
     YUKIO     => 'Yukio Suzuki',
     YUMATSUMO => 'yuya matsumoto',
+    YURYU     => 'Haruka Iwao',
     YOKKUNS   => 'Yohei Sato',
     YUPUG     => 'Yu Isobe',
     YUSUKE    => 'Yusuke Shibata',
